@@ -93,7 +93,9 @@ class TestOptions(unittest.TestCase):
             opts.comparator,
             rocksdb.BytewiseComparator)
 
-        self.assertEqual(rocksdb.CompressionType.no_compression, opts.compression)
+        self.assertIn(opts.compression,
+                      (rocksdb.CompressionType.no_compression,
+                      rocksdb.CompressionType.snappy_compression))
 
         opts.compression = rocksdb.CompressionType.zstd_compression
         self.assertEqual(rocksdb.CompressionType.zstd_compression, opts.compression)
